@@ -193,7 +193,7 @@
     <message>
         <location filename="../mainwindow.cpp" line="315"/>
         <source>Invalid Name</source>
-        <translation type="unfinished"/>
+        <translation>Nom no vàlid</translation>
     </message>
 </context>
 <context>
