@@ -19,17 +19,17 @@
     <message>
         <location filename="../mainwindow.ui" line="54"/>
         <source>Defaults</source>
-        <translation type="unfinished"/>
+        <translation>Predeterminado</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="59"/>
         <source>msdos</source>
-        <translation type="unfinished"/>
+        <translation>msdos</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="64"/>
         <source>gpt</source>
-        <translation type="unfinished"/>
+        <translation>gpt</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="72"/>
@@ -59,7 +59,7 @@
     <message>
         <location filename="../mainwindow.ui" line="166"/>
         <source>Partition Table Type</source>
-        <translation type="unfinished"/>
+        <translation>Tipo de Táboa de particións</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="225"/>
@@ -194,7 +194,7 @@
     <message>
         <location filename="../mainwindow.cpp" line="315"/>
         <source>Invalid Name</source>
-        <translation type="unfinished"/>
+        <translation>Nome non válido</translation>
     </message>
 </context>
 <context>
