@@ -194,7 +194,7 @@
     <message>
         <location filename="../mainwindow.cpp" line="315"/>
         <source>Invalid Name</source>
-        <translation type="unfinished"/>
+        <translation>Emër i Pavlefshëm</translation>
     </message>
 </context>
 <context>
